@@ -21,15 +21,6 @@ namespace Python.EmbeddingTest
             PythonEngine.Shutdown();
         }
 
-        [Test]
-        public void IntPtrCtor()
-        {
-            var i = new PyFloat(1);
-            Runtime.Runtime.XIncref(i.Handle);
-            var ii = new PyFloat(i.Handle);
-            Assert.AreEqual(i.Handle, ii.Handle);
-        }
-
         [Test]
         public void FloatCtor()
         {
@@ -95,7 +86,7 @@ namespace Python.EmbeddingTest
 
             var ex = Assert.Throws<PythonException>(() => a = new PyFloat(i));
 
-            StringAssert.StartsWith("ValueError : could not convert string to float", ex.Message);
+            StringAssert.StartsWith("could not convert string to float", ex.Message);
             Assert.IsNull(a);
         }
 
@@ -132,7 +123,7 @@ namespace Python.EmbeddingTest
             PyFloat a = null;
 
             var ex = Assert.Throws<PythonException>(() => a = PyFloat.AsFloat(s));
-            StringAssert.StartsWith("ValueError : could not convert string to float", ex.Message);
+            StringAssert.StartsWith("could not convert string to float", ex.Message);
             Assert.IsNull(a);
         }
     }
