@@ -1,18 +1,16 @@
-using System;
 using System.Collections;
 
 namespace Python.Test
 {
-    //========================================================================
-    // Supports CLR class unit tests.
-    //========================================================================
-
+    /// <summary>
+    /// Supports CLR class unit tests.
+    /// </summary>
     public class ClassTest
     {
         public static ArrayList GetArrayList()
         {
-            ArrayList list = new ArrayList();
-            for (int i = 0; i < 10; i++)
+            var list = new ArrayList();
+            for (var i = 0; i < 10; i++)
             {
                 list.Add(i);
             }
@@ -21,7 +19,7 @@ namespace Python.Test
 
         public static Hashtable GetHashtable()
         {
-            Hashtable dict = new Hashtable();
+            var dict = new Hashtable();
             dict.Add("one", 1);
             dict.Add("two", 2);
             dict.Add("three", 3);
@@ -32,7 +30,7 @@ namespace Python.Test
 
         public static IEnumerator GetEnumerator()
         {
-            string temp = "test string";
+            var temp = "test string";
             return temp.GetEnumerator();
         }
     }
@@ -61,4 +59,4 @@ namespace Python.Test
     internal class InternalClass
     {
     }
-}
\ No newline at end of file
+}
